==> CycleCommand_v0.01.zip: Interface/AddOns/CycleCommand/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_CYCLECOMMANDHEADER		= "Cycle Command";
BINDING_NAME_CYCLECOMMAND				= "Cycle Command Toggle";

CYCLECOMMAND_CONFIG_HEADER				= "Cycle Command";
CYCLECOMMAND_CONFIG_HEADER_INFO			= "Contains settings for the Cycle Command,\nan AddOn which allows you to create commands which changes behaviour after each execution.";

CYCLECOMMAND_ENABLED					= "Enable Cycle Command";
CYCLECOMMAND_ENABLED_INFO				= "Enables Cycle Command, allowing Cycle Commands to be executed.";

CYCLECOMMAND_CHAT_ENABLED				= "Cycle Command enabled.";
CYCLECOMMAND_CHAT_DISABLED				= "Cycle Command disabled.";

CYCLECOMMAND_CHAT_COMMAND_ENABLE_INFO	= "Enables/disables Cycle Command.";

CYCLECOMMAND_CHAT_COMMAND_CYCLE_INFO	= "Creates, runs or removes a Cycle Command";

CYCLECOMMAND_CHAT_CYCLE_NOCOMMANDS		= "No commands to cycle were specified. Cycle Command not created.";

CYCLECOMMAND_CHAT_NOSUCHCOMMAND			= "No such cycle command \"%s\".";

CYCLECOMMAND_CHAT_RESET					= "Cycle command \"%s\" reset.";


CYCLECOMMAND_CHAT_CYCLE_USAGE			= "Usage : /cyclecommand [<add\|remove\|reset\|run\|update>] commandName [command[##command[##command[...]]]]\ncommandName is case-insensitive.\nCommands should use ## as a seperator between them, as specified above.";

CYCLECOMMAND_COMMAND_SEPERATOR			= "##";


CYCLECOMMAND_CHAT_COMMAND_CREATED		= "Created the %s Cycle Command";
CYCLECOMMAND_CHAT_COMMAND_UPDATED		= "Updated the %s Cycle Command";
CYCLECOMMAND_CHAT_COMMAND_REMOVED		= "Removed the %s Cycle Command";


CYCLECOMMAND_CHAT_IS_DISABLED			= "Cycle Command is currently disabled. No Cycle Commands can be used while it is disabled. Use /cyclecommandenable to activate it.";

==> CycleCommand_v0.03.zip: Interface/AddOns/CycleCommand/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_CYCLECOMMANDHEADER		= "Cycle Command";
BINDING_NAME_CYCLECOMMAND				= "Cycle Command Toggle";

CYCLECOMMAND_CONFIG_HEADER				= "Cycle Command";
CYCLECOMMAND_CONFIG_HEADER_INFO			= "Contains settings for the Cycle Command,\nan AddOn which allows you to create commands which changes behaviour after each execution.";

CYCLECOMMAND_ENABLED					= "Enable Cycle Command";
CYCLECOMMAND_ENABLED_INFO				= "Enables Cycle Command, allowing Cycle Commands to be executed.";

CYCLECOMMAND_CHAT_ENABLED				= "Cycle Command enabled.";
CYCLECOMMAND_CHAT_DISABLED				= "Cycle Command disabled.";

CYCLECOMMAND_CHAT_COMMAND_ENABLE_INFO	= "Enables/disables Cycle Command.";

CYCLECOMMAND_CHAT_COMMAND_CYCLE_INFO	= "Creates, runs or removes a Cycle Command";

CYCLECOMMAND_CHAT_CYCLE_NOCOMMANDS		= "No commands to cycle were specified. Cycle Command not created.";

CYCLECOMMAND_CHAT_NOSUCHCOMMAND			= "No such cycle command \"%s\".";

CYCLECOMMAND_CHAT_RESET					= "Cycle command \"%s\" reset.";


CYCLECOMMAND_CHAT_CYCLE_USAGE			= "Usage : /cyclecommand [<add\|remove\|reset\|run\|update>] commandName [command[##command[##command[...]]]]\ncommandName is case-insensitive.\nCommands should use ## as a seperator between them, as specified above.\nExample:\n/cyclecommand add Smurf /say Smurfs R00lz!!!##/say I'm a l337 Smurf!";

CYCLECOMMAND_COMMAND_SEPERATOR			= "##";


CYCLECOMMAND_CHAT_COMMAND_CREATED		= "Created the %s Cycle Command";
CYCLECOMMAND_CHAT_COMMAND_UPDATED		= "Updated the %s Cycle Command";
CYCLECOMMAND_CHAT_COMMAND_REMOVED		= "Removed the %s Cycle Command";


CYCLECOMMAND_CHAT_IS_DISABLED			= "Cycle Command is currently disabled. No Cycle Commands can be used while it is disabled. Use /cyclecommandenable to activate it.";
